# -*-makefile-*-
# $Id: template 6655 2007-01-02 12:55:21Z rsc $
#
# Copyright (C) 2007 by Juergen Beisert
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_AUDIOFILE) += audiofile

#
# Paths and names
#
AUDIOFILE_VERSION	:= 0.2.6
AUDIOFILE		:= audiofile-$(AUDIOFILE_VERSION)
AUDIOFILE_SUFFIX	:= tar.bz2
AUDIOFILE_URL		:= ftp://gnome/bla/$(AUDIOFILE).$(AUDIOFILE_SUFFIX)
AUDIOFILE_SOURCE	:= $(SRCDIR)/$(AUDIOFILE).$(AUDIOFILE_SUFFIX)
AUDIOFILE_DIR		:= $(BUILDDIR)/$(AUDIOFILE)

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

audiofile_get: $(STATEDIR)/audiofile.get

$(STATEDIR)/audiofile.get: $(audiofile_get_deps_default)
	@$(call targetinfo, $@)
	@$(call touch, $@)

$(AUDIOFILE_SOURCE):
	@$(call targetinfo, $@)
	@$(call get, AUDIOFILE)

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

audiofile_extract: $(STATEDIR)/audiofile.extract

$(STATEDIR)/audiofile.extract: $(audiofile_extract_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(AUDIOFILE_DIR))
	@$(call extract, AUDIOFILE)
	@$(call patchin, AUDIOFILE)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

audiofile_prepare: $(STATEDIR)/audiofile.prepare

AUDIOFILE_PATH	:= PATH=$(CROSS_PATH)
AUDIOFILE_ENV 	:= $(CROSS_ENV)

#
# autoconf
#
# FIXME: It makes more sense to link the el daemon statically to libasound,
# especially on x86 targets!
#
AUDIOFILE_AUTOCONF := $(CROSS_AUTOCONF_USR) \
	--disable-dependency-tracking \
	--disable-largefile

ifdef PTXCONF_AUDIOFILE_STATIC
	AUDIOFILE_AUTOCONF += --enable-static=yes
else
	AUDIOFILE_AUTOCONF += --enable-static=no
endif
ifdef PTXCONF_AUDIOFILE_SHARED
	AUDIOFILE_AUTOCONF += --enable-shared=yes
else
	AUDIOFILE_AUTOCONF += --enable-shared=no
endif

$(STATEDIR)/audiofile.prepare: $(audiofile_prepare_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(AUDIOFILE_DIR)/config.cache)
	cd $(AUDIOFILE_DIR) && \
		$(AUDIOFILE_PATH) $(AUDIOFILE_ENV) \
		./configure $(AUDIOFILE_AUTOCONF)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

audiofile_compile: $(STATEDIR)/audiofile.compile

$(STATEDIR)/audiofile.compile: $(audiofile_compile_deps_default)
	@$(call targetinfo, $@)
	cd $(AUDIOFILE_DIR) && $(AUDIOFILE_PATH) $(MAKE) $(PARALLELMFLAGS)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

audiofile_install: $(STATEDIR)/audiofile.install

$(STATEDIR)/audiofile.install: $(audiofile_install_deps_default)
	@$(call targetinfo, $@)
	@$(call install, AUDIOFILE)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

audiofile_targetinstall: $(STATEDIR)/audiofile.targetinstall

$(STATEDIR)/audiofile.targetinstall: $(audiofile_targetinstall_deps_default)
	@$(call targetinfo, $@)

ifdef PTXCONF_AUDIOFILE_SHARED
	@$(call install_init, audiofile)
	@$(call install_fixup, audiofile,PACKAGE,audiofile)
	@$(call install_fixup, audiofile,PRIORITY,optional)
	@$(call install_fixup, audiofile,VERSION,$(AUDIOFILE_VERSION))
	@$(call install_fixup, audiofile,SECTION,base)
	@$(call install_fixup, audiofile,AUTHOR,"Juergen Beisert <juergen\@kreuzholzen.de>")
	@$(call install_fixup, audiofile,DEPENDS,)
	@$(call install_fixup, audiofile,DESCRIPTION,missing)

	@$(call install_copy, audiofile, 0, 0, 0755, \
		$(AUDIOFILE_DIR)/libaudiofile/.libs/libaudiofile.so.0.0.2, \
		/usr/lib/libaudiofile.so.0.0.2)

	@$(call install_link, audiofile, \
		libaudiofile.so.0.0.2, \
		/usr/lib/libaudiofile.so)

	@$(call install_link, audiofile, \
		libaudiofile.so.0.0.2, \
		/usr/lib/libaudiofile.so.0)

	@$(call install_finish, audiofile)
endif
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

audiofile_clean:
	rm -rf $(STATEDIR)/audiofile.*
	rm -rf $(IMAGEDIR)/audiofile_*
	rm -rf $(AUDIOFILE_DIR)

# vim: syntax=make
