# -*-makefile-*-
# $Id: template 6655 2007-01-02 12:55:21Z rsc $
#
# Copyright (C) 2007 by Juergen Beisert
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_AVRDUDE) += avrdude

#
# Paths and names
#
AVRDUDE_VERSION		:= 5.4
AVRDUDE			:= avrdude-$(AVRDUDE_VERSION)
AVRDUDE_SUFFIX		:= tar.gz
AVRDUDE_URL		:= http://download.savannah.gnu.org/releases/avrdude/$(AVRDUDE).$(AVRDUDE_SUFFIX)
AVRDUDE_SOURCE		:= $(SRCDIR)/$(AVRDUDE).$(AVRDUDE_SUFFIX)
AVRDUDE_DIR		:= $(BUILDDIR)/$(AVRDUDE)

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

avrdude_get: $(STATEDIR)/avrdude.get

$(STATEDIR)/avrdude.get: $(avrdude_get_deps_default)
	@$(call targetinfo, $@)
	@$(call touch, $@)

$(AVRDUDE_SOURCE):
	@$(call targetinfo, $@)
	@$(call get, AVRDUDE)

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

avrdude_extract: $(STATEDIR)/avrdude.extract

$(STATEDIR)/avrdude.extract: $(avrdude_extract_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(AVRDUDE_DIR))
	@$(call extract, AVRDUDE)
	@$(call patchin, AVRDUDE)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

avrdude_prepare: $(STATEDIR)/avrdude.prepare

AVRDUDE_PATH	:= PATH=$(CROSS_PATH)
AVRDUDE_ENV 	:= $(CROSS_ENV)

#
# autoconf
# Note: the malloc test fails for cross compile
# It will replace malloc by rpl_malloc and the linking step fails.
# So we enable the GNU malloc by default here.
#
AVRDUDE_AUTOCONF := $(CROSS_AUTOCONF_USR)  \
		ac_cv_func_malloc_0_nonnull=yes \
		--disable-doc \
		--disable-parport

$(STATEDIR)/avrdude.prepare: $(avrdude_prepare_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(AVRDUDE_DIR)/config.cache)
	cd $(AVRDUDE_DIR) && \
		$(AVRDUDE_PATH) $(AVRDUDE_ENV) \
		./configure $(AVRDUDE_AUTOCONF)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

avrdude_compile: $(STATEDIR)/avrdude.compile

$(STATEDIR)/avrdude.compile: $(avrdude_compile_deps_default)
	@$(call targetinfo, $@)
	cd $(AVRDUDE_DIR) && $(AVRDUDE_PATH) $(MAKE) $(PARALLELMFLAGS)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

avrdude_install: $(STATEDIR)/avrdude.install

$(STATEDIR)/avrdude.install: $(avrdude_install_deps_default)
	@$(call targetinfo, $@)
#	@$(call install, AVRDUDE)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

avrdude_targetinstall: $(STATEDIR)/avrdude.targetinstall

$(STATEDIR)/avrdude.targetinstall: $(avrdude_targetinstall_deps_default)
	@$(call targetinfo, $@)

	@$(call install_init, avrdude)
	@$(call install_fixup, avrdude,PACKAGE,avrdude)
	@$(call install_fixup, avrdude,PRIORITY,optional)
	@$(call install_fixup, avrdude,VERSION,$(AVRDUDE_VERSION))
	@$(call install_fixup, avrdude,SECTION,base)
	@$(call install_fixup, avrdude,AUTHOR,"Robert Schwebel <r.schwebel\@pengutronix.de>")
	@$(call install_fixup, avrdude,DEPENDS,)
	@$(call install_fixup, avrdude,DESCRIPTION,missing)

	@$(call install_copy, avrdude, 0, 0, 0755, $(AVRDUDE_DIR)/avrdude, /bin/avrdude)
	@$(call install_copy, avrdude, 0, 0, 0755, $(AVRDUDE_DIR)/avrdude.conf, /etc/avrdude.conf,n)

	@$(call install_finish, avrdude)

	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

avrdude_clean:
	rm -rf $(STATEDIR)/avrdude.*
	rm -rf $(IMAGEDIR)/avrdude_*
	rm -rf $(AVRDUDE_DIR)

