#
# Copyright (C) 2008 by Juergen Beisert
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_LIBFTDI) += libftdi

#
# Paths and names
#
LIBFTDI_VERSION	:= 0.10
LIBFTDI		:= libftdi-$(LIBFTDI_VERSION)
LIBFTDI_SUFFIX	:= tar.gz
LIBFTDI_URL	:= http://www.intra2net.com/de/produkte/opensource/ftdi/TGZ/$(LIBFTDI).$(LIBFTDI_SUFFIX)
LIBFTDI_SOURCE	:= $(SRCDIR)/$(LIBFTDI).$(LIBFTDI_SUFFIX)
LIBFTDI_DIR	:= $(BUILDDIR)/$(LIBFTDI)

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

libftdi_get: $(STATEDIR)/libftdi.get

$(STATEDIR)/libftdi.get: $(libftdi_get_deps_default)
	@$(call targetinfo, $@)
	@$(call touch, $@)

$(LIBFTDI_SOURCE):
	@$(call targetinfo, $@)
	@$(call get, LIBFTDI)

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

libftdi_extract: $(STATEDIR)/libftdi.extract

$(STATEDIR)/libftdi.extract: $(libftdi_extract_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(LIBFTDI_DIR))
	@$(call extract, LIBFTDI)
	@$(call patchin, LIBFTDI)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

libftdi_prepare: $(STATEDIR)/libftdi.prepare

LIBFTDI_PATH	:= PATH=$(CROSS_PATH)
LIBFTDI_ENV 	:= $(CROSS_ENV)

#
# autoconf
#
LIBFTDI_AUTOCONF := $(CROSS_AUTOCONF_USR) \
	--disable-dependency-tracking \
	--disable-debug \
	HAVELIBUSB="$(PTXCONF_CROSS_PREFIX)/bin/pkg-config libusb"
# required, as long this packet uses libusb-config instead of pkgconfig

ifdef PTXCONF_LIBFTDI_SHARED
LIBFTDI_AUTOCONF += --enable-shared
else
LIBFTDI_AUTOCONF += --enable-shared=no
endif
ifdef PTXCONF_LIBFTDI_STATIC
LIBFTDI_AUTOCONF += --enable-static
else
LIBFTDI_AUTOCONF += --enable-static=no
endif

$(STATEDIR)/libftdi.prepare: $(libftdi_prepare_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(LIBFTDI_DIR)/config.cache)
	cd $(LIBFTDI_DIR) && \
		$(LIBFTDI_PATH) $(LIBFTDI_ENV) \
		./configure $(LIBFTDI_AUTOCONF)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

libftdi_compile: $(STATEDIR)/libftdi.compile

$(STATEDIR)/libftdi.compile: $(libftdi_compile_deps_default)
	@$(call targetinfo, $@)
	cd $(LIBFTDI_DIR) && $(LIBFTDI_PATH) $(MAKE) $(PARALLELMFLAGS)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

libftdi_install: $(STATEDIR)/libftdi.install

$(STATEDIR)/libftdi.install: $(libftdi_install_deps_default)
	@$(call targetinfo, $@)
	@$(call install, LIBFTDI)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

libftdi_targetinstall: $(STATEDIR)/libftdi.targetinstall

$(STATEDIR)/libftdi.targetinstall: $(libftdi_targetinstall_deps_default)
	@$(call targetinfo, $@)

ifdef PTXCONF_LIBFTDI_SHARED
	@$(call install_init, libftdi)
	@$(call install_fixup, libftdi,PACKAGE,libftdi)
	@$(call install_fixup, libftdi,PRIORITY,optional)
	@$(call install_fixup, libftdi,VERSION,$(LIBFTDI_VERSION))
	@$(call install_fixup, libftdi,SECTION,base)
	@$(call install_fixup, libftdi,AUTHOR,"Juergen Beisert <juergen\@kreuzholzen.de>")
	@$(call install_fixup, libftdi,DEPENDS,)
	@$(call install_fixup, libftdi,DESCRIPTION,missing)

	@$(call install_copy, libftdi, 0, 0, 0755, \
		$(LIBFTDI_DIR)/src/.libs/libftdi.so.0.10.0, \
		/usr/lib/libftdi.so.0.10.0, y)
	@$(call install_link, libftdi, \
		libftdi.so.0.10.0, /usr/lib/libftdi.so.0)
	@$(call install_link, libftdi, \
		libftdi.so.0.10.0, /usr/lib/libftdi.so)

	@$(call install_finish, libftdi)
endif
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

libftdi_clean:
	rm -rf $(STATEDIR)/libftdi.*
	rm -rf $(IMAGEDIR)/libftdi_*
	rm -rf $(LIBFTDI_DIR)

# vim: syntax=make
